@@ -216,6 +216,11 @@ bool DQMLGlobalObject::hasNoTitlebar() const
     return DWindowManagerHelper::instance()->hasNoTitlebar();
 }
 
+bool DQMLGlobalObject::hasAnimation()
+{
+    return DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::HasAnimations);
+}
+
 bool DQMLGlobalObject::isSoftwareRender()
 {
     static bool isSoftware = QQuickWindow::sceneGraphBackend() == QLatin1String("software");
